pub struct FunctionRoutineVerifyEvent {
pub routine: Pubkey,
pub function: Pubkey,
pub verifier: Pubkey,
pub mr_enclave: Vec<u8>,
pub container_registry: Vec<u8>,
pub container: Vec<u8>,
pub params: Vec<u8>,
}Fields
routine: Pubkeyfunction: Pubkeyverifier: Pubkeymr_enclave: Vec<u8>container_registry: Vec<u8>container: Vec<u8>params: Vec<u8>Trait Implementations
Sourceimpl BorshDeserialize for FunctionRoutineVerifyEvent
impl BorshDeserialize for FunctionRoutineVerifyEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for FunctionRoutineVerifyEvent
impl Discriminator for FunctionRoutineVerifyEvent
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]