Struct switchboard_solana::attestation_program::instructions::function_init::FunctionInitParams
source · pub struct FunctionInitParams {Show 14 fields
pub recent_slot: u64,
pub creator_seed: Option<[u8; 32]>,
pub name: Vec<u8>,
pub metadata: Vec<u8>,
pub container: Vec<u8>,
pub container_registry: Vec<u8>,
pub version: Vec<u8>,
pub mr_enclave: Option<[u8; 32]>,
pub requests_disabled: bool,
pub requests_require_authorization: bool,
pub requests_dev_fee: u64,
pub routines_disabled: bool,
pub routines_require_authorization: bool,
pub routines_dev_fee: u64,
}Fields
recent_slot: u64creator_seed: Option<[u8; 32]>name: Vec<u8>metadata: Vec<u8>container: Vec<u8>container_registry: Vec<u8>version: Vec<u8>mr_enclave: Option<[u8; 32]>requests_disabled: boolrequests_dev_fee: u64routines_disabled: boolroutines_dev_fee: u64Trait Implementations
sourceimpl BorshDeserialize for FunctionInitParamswhere
u64: BorshDeserialize,
Option<[u8; 32]>: BorshDeserialize,
Vec<u8>: BorshDeserialize,
bool: BorshDeserialize,
impl BorshDeserialize for FunctionInitParamswhere
u64: BorshDeserialize,
Option<[u8; 32]>: BorshDeserialize,
Vec<u8>: BorshDeserialize,
bool: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
sourceimpl BorshSerialize for FunctionInitParamswhere
u64: BorshSerialize,
Option<[u8; 32]>: BorshSerialize,
Vec<u8>: BorshSerialize,
bool: BorshSerialize,
impl BorshSerialize for FunctionInitParamswhere
u64: BorshSerialize,
Option<[u8; 32]>: BorshSerialize,
Vec<u8>: BorshSerialize,
bool: BorshSerialize,
sourceimpl Clone for FunctionInitParams
impl Clone for FunctionInitParams
sourcefn clone(&self) -> FunctionInitParams
fn clone(&self) -> FunctionInitParams
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Default for FunctionInitParams
impl Default for FunctionInitParams
sourcefn default() -> FunctionInitParams
fn default() -> FunctionInitParams
Returns the “default value” for a type. Read more
sourceimpl Discriminator for FunctionInitParams
impl Discriminator for FunctionInitParams
const DISCRIMINATOR: [u8; 8] = _
fn discriminator() -> [u8; 8]