pub struct FunctionSetConfigParams {
pub name: Option<Vec<u8>>,
pub metadata: Option<Vec<u8>>,
pub container: Option<Vec<u8>>,
pub container_registry: Option<Vec<u8>>,
pub version: Option<Vec<u8>>,
pub schedule: Option<Vec<u8>>,
pub mr_enclaves: Option<Vec<[u8; 32]>>,
pub requests_disabled: Option<bool>,
pub requests_require_authorization: Option<bool>,
pub requests_fee: Option<u64>,
}Fields
name: Option<Vec<u8>>metadata: Option<Vec<u8>>container: Option<Vec<u8>>container_registry: Option<Vec<u8>>version: Option<Vec<u8>>schedule: Option<Vec<u8>>mr_enclaves: Option<Vec<[u8; 32]>>requests_disabled: Option<bool>requests_fee: Option<u64>Trait Implementations
Sourceimpl BorshDeserialize for FunctionSetConfigParamswhere
Option<Vec<u8>>: BorshDeserialize,
Option<Vec<[u8; 32]>>: BorshDeserialize,
Option<bool>: BorshDeserialize,
Option<u64>: BorshDeserialize,
impl BorshDeserialize for FunctionSetConfigParamswhere
Option<Vec<u8>>: BorshDeserialize,
Option<Vec<[u8; 32]>>: BorshDeserialize,
Option<bool>: BorshDeserialize,
Option<u64>: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for FunctionSetConfigParamswhere
Option<Vec<u8>>: BorshSerialize,
Option<Vec<[u8; 32]>>: BorshSerialize,
Option<bool>: BorshSerialize,
Option<u64>: BorshSerialize,
impl BorshSerialize for FunctionSetConfigParamswhere
Option<Vec<u8>>: BorshSerialize,
Option<Vec<[u8; 32]>>: BorshSerialize,
Option<bool>: BorshSerialize,
Option<u64>: BorshSerialize,
Sourceimpl Clone for FunctionSetConfigParams
impl Clone for FunctionSetConfigParams
Sourcefn clone(&self) -> FunctionSetConfigParams
fn clone(&self) -> FunctionSetConfigParams
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Discriminator for FunctionSetConfigParams
impl Discriminator for FunctionSetConfigParams
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]