Struct FunctionVerifyAccounts

pub struct FunctionVerifyAccounts {
    pub function: Pubkey,
    pub function_enclave_signer: Pubkey,
    pub function_escrow: Pubkey,
    pub verifier: Pubkey,
    pub verifier_enclave_signer: Pubkey,
    pub reward_receiver: Pubkey,
    pub attestation_queue: Pubkey,
    pub queue_authority: Pubkey,
}
Available on non-target_os="solana" only.

Fields

function: Pubkey

The FunctionAccount pubkey to verify.

function_enclave_signer: Pubkey

The pubkey of the enclave generated keypair that will be set after verification. This keypair must sign any subsequent instructions to prove the instructions were generated within an enclave.

function_escrow: Pubkey

The Function’s SwitchboardWallet pubkey used to reward verifiers.

verifier: Pubkey

The VerifierAccount pubkey that is verifying the request.

verifier_enclave_signer: Pubkey

The VerifierAccount’s enclave generated signer that must approve verifications.

reward_receiver: Pubkey

The VerifierAccount’s token wallet to receive a reward for verifying the request.

attestation_queue: Pubkey

The AttestationQueueAccount that the request is being verified for.

queue_authority: Pubkey

The AttestationQueueAccount’s authority. Used to derive the VerifierAccount’s permission account.