pub struct FunctionVerifyParams {
pub observed_time: i64,
pub next_allowed_timestamp: i64,
pub error_code: u8,
pub mr_enclave: [u8; 32],
}Fields
observed_time: i64next_allowed_timestamp: i64error_code: u8mr_enclave: [u8; 32]Trait Implementations
Sourceimpl BorshDeserialize for FunctionVerifyParams
impl BorshDeserialize for FunctionVerifyParams
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for FunctionVerifyParams
impl Clone for FunctionVerifyParams
Sourcefn clone(&self) -> FunctionVerifyParams
fn clone(&self) -> FunctionVerifyParams
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Discriminator for FunctionVerifyParams
impl Discriminator for FunctionVerifyParams
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]