pub struct FunctionRequestInit<'info> {
pub request: AccountInfo<'info>,
pub authority: AccountInfo<'info>,
pub function: AccountInfo<'info>,
pub function_authority: Option<AccountInfo<'info>>,
pub escrow: AccountInfo<'info>,
pub mint: AccountInfo<'info>,
pub state: AccountInfo<'info>,
pub attestation_queue: AccountInfo<'info>,
pub payer: AccountInfo<'info>,
pub system_program: AccountInfo<'info>,
pub token_program: AccountInfo<'info>,
pub associated_token_program: AccountInfo<'info>,
}Fields
request: AccountInfo<'info>CHECK: the authority of the request
function: AccountInfo<'info>CHECK: function authority required to permit new requests
escrow: AccountInfo<'info>mint: AccountInfo<'info>state: AccountInfo<'info>attestation_queue: AccountInfo<'info>payer: AccountInfo<'info>system_program: AccountInfo<'info>token_program: AccountInfo<'info>associated_token_program: AccountInfo<'info>Implementations
Sourceimpl<'info> FunctionRequestInit<'info>
impl<'info> FunctionRequestInit<'info>
pub fn get_instruction( &self, program_id: Pubkey, params: FunctionRequestInitParams, ) -> Result<Instruction>
Sourcepub fn invoke(
&self,
program: AccountInfo<'info>,
max_container_params_len: Option<u32>,
container_params: Option<Vec<u8>>,
garbage_collection_slot: Option<u64>,
) -> ProgramResult
pub fn invoke( &self, program: AccountInfo<'info>, max_container_params_len: Option<u32>, container_params: Option<Vec<u8>>, garbage_collection_slot: Option<u64>, ) -> ProgramResult
Invokes the instruction using a signed authority.
Arguments
-
program: The Switchboard Attestation program AccountInfo. -
max_container_params_len: The maximum length of the vector containing the container parameters.- Default: 256 bytes.
- Example:
Some(512).
-
container_params: The parameters for the container.- Default: Empty vector.
- Example:
Some(request_params.into_bytes()).
-
garbage_collection_slot: The slot when the request can be closed by anyone and is considered expired.- Default: None, meaning only the authority can close the request.
Returns
ProgramResult: Indicates the result of the instruction execution.
Sourcepub fn invoke_signed(
&self,
program: AccountInfo<'info>,
max_container_params_len: Option<u32>,
container_params: Option<Vec<u8>>,
garbage_collection_slot: Option<u64>,
signer_seeds: &[&[&[u8]]],
) -> ProgramResult
pub fn invoke_signed( &self, program: AccountInfo<'info>, max_container_params_len: Option<u32>, container_params: Option<Vec<u8>>, garbage_collection_slot: Option<u64>, signer_seeds: &[&[&[u8]]], ) -> ProgramResult
Invokes the instruction using a signed authority.
Arguments
-
program: The Switchboard Attestation program AccountInfo. -
max_container_params_len: The maximum length of the vector containing the container parameters.- Default: 256 bytes.
- Example:
Some(512).
-
container_params: The parameters for the container.- Default: Empty vector.
- Example:
Some(request_params.into_bytes()).
-
garbage_collection_slot: The slot when the request can be closed by anyone and is considered expired.- Default: None, meaning only the authority can close the request.
-
signer_seeds: Seeds used for signing.
Returns
ProgramResult: Indicates the result of the instruction execution.