Struct switchboard_solana::attestation_program::instructions::request_init_and_trigger::FunctionRequestInitAndTriggerParams
source · pub struct FunctionRequestInitAndTriggerParams {
pub bounty: Option<u64>,
pub slots_until_expiration: Option<u64>,
pub max_container_params_len: Option<u32>,
pub container_params: Option<Vec<u8>>,
pub garbage_collection_slot: Option<u64>,
pub valid_after_slot: Option<u64>,
}Fields
bounty: Option<u64>slots_until_expiration: Option<u64>max_container_params_len: Option<u32>container_params: Option<Vec<u8>>garbage_collection_slot: Option<u64>valid_after_slot: Option<u64>Trait Implementations
sourceimpl BorshDeserialize for FunctionRequestInitAndTriggerParamswhere
Option<u64>: BorshDeserialize,
Option<u32>: BorshDeserialize,
Option<Vec<u8>>: BorshDeserialize,
impl BorshDeserialize for FunctionRequestInitAndTriggerParamswhere
Option<u64>: BorshDeserialize,
Option<u32>: BorshDeserialize,
Option<Vec<u8>>: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
sourceimpl Clone for FunctionRequestInitAndTriggerParams
impl Clone for FunctionRequestInitAndTriggerParams
sourcefn clone(&self) -> FunctionRequestInitAndTriggerParams
fn clone(&self) -> FunctionRequestInitAndTriggerParams
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Default for FunctionRequestInitAndTriggerParams
impl Default for FunctionRequestInitAndTriggerParams
sourcefn default() -> FunctionRequestInitAndTriggerParams
fn default() -> FunctionRequestInitAndTriggerParams
Returns the “default value” for a type. Read more
sourceimpl Discriminator for FunctionRequestInitAndTriggerParams
impl Discriminator for FunctionRequestInitAndTriggerParams
const DISCRIMINATOR: [u8; 8] = _
fn discriminator() -> [u8; 8]