Struct switchboard_solana::attestation_program::instructions::request_verify::FunctionRequestVerifyAccounts
source · pub struct FunctionRequestVerifyAccounts {
pub request: Pubkey,
pub function_enclave_signer: Pubkey,
pub function: Pubkey,
pub function_escrow_token_wallet: Option<Pubkey>,
pub verifier: Pubkey,
pub verifier_enclave_signer: Pubkey,
pub reward_receiver: Pubkey,
pub attestation_queue: Pubkey,
pub queue_authority: Pubkey,
}target_os="solana" only.Fields
request: PubkeyThe FunctionRequestAccount pubkey to verify.
function_enclave_signer: PubkeyThe pubkey of the enclave generated keypair that will be set after verification. This keypair must sign any subsequent instructions to prove the instructions were generated within an enclave.
function: PubkeyThe FunctionAccount for the request being verified.
function_escrow_token_wallet: Option<Pubkey>The FunctionAccount escrow token wallet. Only used if the FunctionAccount has a request_fee set.
verifier: PubkeyThe VerifierAccount pubkey that is verifying the request.
verifier_enclave_signer: PubkeyThe VerifierAccount’s enclave generated signer that must approve verifications.
reward_receiver: PubkeyTHe VerifierAccount’s token wallet to receive a reward for verifying the request.
attestation_queue: PubkeyThe AttestationQueueAccount that the request is being verified for.
The AttestationQueueAccount’s authority. Used to derive the VerifierAccount’s permission account.