Struct switchboard_solana::attestation_program::instructions::request_verify::FunctionRequestVerifyParams
source · pub struct FunctionRequestVerifyParams {
pub observed_time: i64,
pub error_code: u8,
pub mr_enclave: [u8; 32],
pub request_slot: u64,
pub container_params_hash: [u8; 32],
}Fields
observed_time: i64error_code: u8mr_enclave: [u8; 32]request_slot: u64container_params_hash: [u8; 32]Trait Implementations
sourceimpl BorshDeserialize for FunctionRequestVerifyParamswhere
i64: BorshDeserialize,
u8: BorshDeserialize,
[u8; 32]: BorshDeserialize,
u64: BorshDeserialize,
impl BorshDeserialize for FunctionRequestVerifyParamswhere
i64: BorshDeserialize,
u8: BorshDeserialize,
[u8; 32]: BorshDeserialize,
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
sourceimpl Clone for FunctionRequestVerifyParams
impl Clone for FunctionRequestVerifyParams
sourcefn clone(&self) -> FunctionRequestVerifyParams
fn clone(&self) -> FunctionRequestVerifyParams
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Discriminator for FunctionRequestVerifyParams
impl Discriminator for FunctionRequestVerifyParams
const DISCRIMINATOR: [u8; 8] = _
fn discriminator() -> [u8; 8]