Struct switchboard_solana::attestation_program::instructions::routine_init::FunctionRoutineInitParams
source · pub struct FunctionRoutineInitParams {
pub name: Option<Vec<u8>>,
pub metadata: Option<Vec<u8>>,
pub bounty: Option<u64>,
pub schedule: Vec<u8>,
pub max_container_params_len: Option<u32>,
pub container_params: Vec<u8>,
}Fields
name: Option<Vec<u8>>metadata: Option<Vec<u8>>bounty: Option<u64>schedule: Vec<u8>max_container_params_len: Option<u32>container_params: Vec<u8>Trait Implementations
sourceimpl BorshDeserialize for FunctionRoutineInitParamswhere
Option<Vec<u8>>: BorshDeserialize,
Option<u64>: BorshDeserialize,
Vec<u8>: BorshDeserialize,
Option<u32>: BorshDeserialize,
impl BorshDeserialize for FunctionRoutineInitParamswhere
Option<Vec<u8>>: BorshDeserialize,
Option<u64>: BorshDeserialize,
Vec<u8>: BorshDeserialize,
Option<u32>: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
sourceimpl BorshSerialize for FunctionRoutineInitParamswhere
Option<Vec<u8>>: BorshSerialize,
Option<u64>: BorshSerialize,
Vec<u8>: BorshSerialize,
Option<u32>: BorshSerialize,
impl BorshSerialize for FunctionRoutineInitParamswhere
Option<Vec<u8>>: BorshSerialize,
Option<u64>: BorshSerialize,
Vec<u8>: BorshSerialize,
Option<u32>: BorshSerialize,
sourceimpl Clone for FunctionRoutineInitParams
impl Clone for FunctionRoutineInitParams
sourcefn clone(&self) -> FunctionRoutineInitParams
fn clone(&self) -> FunctionRoutineInitParams
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Discriminator for FunctionRoutineInitParams
impl Discriminator for FunctionRoutineInitParams
const DISCRIMINATOR: [u8; 8] = _
fn discriminator() -> [u8; 8]