pub struct BootstrapAttestationQueueParams {
pub reward: Option<u32>,
pub allow_authority_override_after: Option<u32>,
pub max_quote_verification_age: Option<u32>,
pub require_authority_heartbeat_permission: Option<bool>,
pub require_usage_permissions: Option<bool>,
pub node_timeout: Option<u32>,
pub verifier_enclave: Option<Vec<u8>>,
pub registry_key: Option<Vec<u8>>,
}Available on non-
target_os="solana" only.Expand description
Parameters used to initialize the bootstrapped attestation queue.
Fields
reward: Option<u32>max_quote_verification_age: Option<u32>require_usage_permissions: Option<bool>node_timeout: Option<u32>verifier_enclave: Option<Vec<u8>>registry_key: Option<Vec<u8>>Trait Implementations
sourceimpl BorshDeserialize for BootstrapAttestationQueueParamswhere
Option<u32>: BorshDeserialize,
Option<bool>: BorshDeserialize,
Option<Vec<u8>>: BorshDeserialize,
impl BorshDeserialize for BootstrapAttestationQueueParamswhere
Option<u32>: BorshDeserialize,
Option<bool>: BorshDeserialize,
Option<Vec<u8>>: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
sourceimpl Clone for BootstrapAttestationQueueParams
impl Clone for BootstrapAttestationQueueParams
sourcefn clone(&self) -> BootstrapAttestationQueueParams
fn clone(&self) -> BootstrapAttestationQueueParams
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for BootstrapAttestationQueueParams
impl RefUnwindSafe for BootstrapAttestationQueueParams
impl Send for BootstrapAttestationQueueParams
impl Sync for BootstrapAttestationQueueParams
impl Unpin for BootstrapAttestationQueueParams
impl UnwindSafe for BootstrapAttestationQueueParams