pub struct FunctionInitAccounts {
pub function: Pubkey,
pub address_lookup_table: Pubkey,
pub authority: Pubkey,
pub attestation_queue: Pubkey,
pub payer: Pubkey,
pub escrow_wallet: Pubkey,
pub escrow_wallet_authority: Option<Pubkey>,
}Available on non-
target_os="solana" only.Fields
function: Pubkeyaddress_lookup_table: Pubkeyattestation_queue: Pubkeypayer: Pubkeyescrow_wallet: PubkeyTrait Implementations
sourceimpl ToAccountMetas for FunctionInitAccounts
impl ToAccountMetas for FunctionInitAccounts
sourcefn to_account_metas(&self, _: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, _: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for FunctionInitAccounts
impl RefUnwindSafe for FunctionInitAccounts
impl Send for FunctionInitAccounts
impl Sync for FunctionInitAccounts
impl Unpin for FunctionInitAccounts
impl UnwindSafe for FunctionInitAccounts