pub struct LegacyFunctionResult {
pub version: u32,
pub quote: Vec<u8>,
pub fn_key: Vec<u8>,
pub signer: Vec<u8>,
pub fn_request_key: Vec<u8>,
pub fn_request_hash: Vec<u8>,
pub chain_result_info: LegacyChainResultInfo,
pub error_code: u8,
}Expand description
The schema of the output data that will be sent to the quote verification sidecar.
This implementation has been deprecated in favor of FunctionResult.
Fields
version: u32version of the output format
quote: Vec<u8>Buffer containing the quote signing the output
fn_key: Vec<u8>key of the executed function
signer: Vec<u8>The oracle’s signer used to sign off on the execution
fn_request_key: Vec<u8>If the call was a funciton request, the address of the request account.
fn_request_hash: Vec<u8>A sha-256 hash of the parameters used in this request call.
chain_result_info: LegacyChainResultInfoChain specific info
error_code: u8On function failure, users should emit with error code to avoid aggressive backoffs