pub struct FunctionVerifyAccounts {
pub function: Pubkey,
pub function_enclave_signer: Pubkey,
pub function_escrow: Pubkey,
pub verifier: Pubkey,
pub verifier_enclave_signer: Pubkey,
pub reward_receiver: Pubkey,
pub attestation_queue: Pubkey,
pub queue_authority: Pubkey,
}Available on non-
target_os="solana" only.Fields
function: PubkeyThe FunctionAccount pubkey to verify.
function_enclave_signer: PubkeyThe pubkey of the enclave generated keypair that will be set after verification. This keypair must sign any subsequent instructions to prove the instructions were generated within an enclave.
function_escrow: PubkeyThe Function’s SwitchboardWallet pubkey used to reward verifiers.
verifier: PubkeyThe VerifierAccount pubkey that is verifying the request.
verifier_enclave_signer: PubkeyThe VerifierAccount’s enclave generated signer that must approve verifications.
reward_receiver: PubkeyThe VerifierAccount’s token wallet to receive a reward for verifying the request.
attestation_queue: PubkeyThe AttestationQueueAccount that the request is being verified for.
The AttestationQueueAccount’s authority. Used to derive the VerifierAccount’s permission account.